@@ -24,19 +24,21 @@
  * \param fileName File name for exported bitmap. Extension determines format.
  * \param properties Various properties:
  *
- *  properties["width"]: width of bitmap in pixels (ignored if resolution is present)
- *  properties["height"]: height of bitmap in pixels (ignored if resolution is present)
- *  properties["resolution"]: resolution in pixels / drawing unit
- *  properties["margin"]: margin at borders in pixels
- *  properties["backgroundColor"]: background color (RColor)
- *  properties["origin"]: true: export origin point as red cross
- *  properties["antialiasing"]: true: use antialiasing
- *  properties["quality"]: Export quality (0..100), JPEG only
- *  properties["monochrome"]: true: Export as black / white
- *  properties["grayscale"]: true: Export as grayscale
- *  properties["window"]: RBox: window to export in drawing coordinates
- *  properties["entityids"]: Array: zoom to bounding box of given entities
- *  properties["initView"]: Callback to initialize view
+ *  - properties["width"]: width of bitmap in pixels (ignored if resolution is present)
+ *  - properties["height"]: height of bitmap in pixels (ignored if resolution is present)
+ *  - properties["resolution"]: resolution in pixels / drawing unit
+ *  - properties["margin"]: margin at borders in pixels
+ *  - properties["noWeightMargin"]: true to disable margin for lineweight, defaults to false
+ *  - properties["backgroundColor"]: background color (RColor)
+ *  - properties["origin"]: true: export origin point as red cross
+ *  - properties["antialiasing"]: true: use antialiasing
+ *  - properties["quality"]: Export quality (0..100), JPEG only
+ *  - properties["monochrome"]: true: Export as black / white
+ *  - properties["grayscale"]: true: Export as grayscale
+ *  - properties["window"]: RBox: window to export in drawing coordinates
+ *  - properties["entityIds"]: Array: zoom to bounding box of given entities
+ *  - properties["initView"]: Callback to initialize view
+ *  - properties["zoomAll"]: Auto zoom to all entities, including those on invisible layers
  *
  * \param view Optional graphics view to use.
  */
@@ -49,6 +51,10 @@ function exportBitmap(doc, scene, fileName, properties, view) {
         view.setScene(scene, false);
         viewCreated = true;
     }
+    var numThreadsOri = view.getNumThreads();
+
+    // crashes with multiple threads:
+    view.setNumThreads(1);
     view.setAlphaEnabled(true);
 
     view.setPaintOrigin(properties["origin"]==null ? false : properties["origin"]);
@@ -74,22 +80,29 @@ function exportBitmap(doc, scene, fileName, properties, view) {
         properties["margin"] = 20;
     }
 
-    if (typeof(properties["noweightmargin"])==="undefined") {
-        properties["noweightmargin"] = false;
+    if (typeof(properties["noWeightMargin"])==="undefined") {
+        properties["noWeightMargin"] = false;
     }
 
-    if (typeof(properties["zoomall"])==="undefined") {
-        properties["zoomall"] = false;
+    if (typeof(properties["zoomAll"])==="undefined") {
+        properties["zoomAll"] = false;
     }
 
     if (properties["resolution"]) {
         var bb;
-        if (typeof(properties["entityids"])!=="undefined") {
-            bb = doc.getEntitiesBox(properties["entityids"]);
+        if (typeof(properties["entityIds"])!=="undefined") {
+            bb = doc.getEntitiesBox(properties["entityIds"]);
         }
         else {
             bb = doc.getBoundingBox(true, true);
         }
+
+        if (properties["noWeightMargin"]===false) {
+            // grow bounding box by max line weight:
+            var wm = RUnit.convert(doc.getMaxLineweight()/100.0/2, RS.Millimeter, doc.getUnit());
+            bb.growXY(wm);
+        }
+
         properties["width"] = Math.ceil(bb.getWidth() * properties["resolution"] + 2 * properties["margin"]);
         properties["height"] = Math.ceil(bb.getHeight() * properties["resolution"] + 2 * properties["margin"]);
     }
@@ -104,6 +117,7 @@ function exportBitmap(doc, scene, fileName, properties, view) {
     if (properties["width"] * properties["height"] > 2147483647/4) {
         qDebug("invalid image size");
         ret = [ false, qsTr("Invalid image size (width x height must be less than %1)").arg(536870911) ];
+        view.setNumThreads(numThreadsOri);
         return ret;
     }
 
@@ -112,15 +126,15 @@ function exportBitmap(doc, scene, fileName, properties, view) {
     if (properties["window"]) {
         view.zoomTo(properties["window"], properties["margin"]);
     }
-    else if (properties["zoomall"]) {
-        var bbz = doc.getBoundingBox(false);
+    else if (properties["zoomAll"]) {
+        var bbz = doc.getBoundingBox(false, true);
         view.zoomTo(bbz, properties["margin"]);
     }
-    else if (typeof(properties["entityids"])!=="undefined") {
-        view.zoomToEntities(properties["entityids"], properties["margin"]);
+    else if (typeof(properties["entityIds"])!=="undefined") {
+        view.zoomToEntities(properties["entityIds"], properties["margin"]);
     }
     else {
-        view.autoZoom(properties["margin"], true, properties["noweightmargin"]);
+        view.autoZoom(properties["margin"], true, properties["noWeightMargin"]);
     }
 
     // make sure we use the desired resolution:
@@ -145,6 +159,7 @@ function exportBitmap(doc, scene, fileName, properties, view) {
     // export file
     var buffer = view.getBuffer();
 
+    view.setNumThreads(numThreadsOri);
     if (viewCreated) {
         scene.unregisterView(view);
         view.destroy();
